#[repr(transparent)]pub struct Fall(pub u32);Expand description
Pin interrupt falling edge register
Tuple Fields
0: u32Implementations
Sourceimpl Fall
impl Fall
Sourcepub const fn fdet(&self) -> u8
pub const fn fdet(&self) -> u8
Falling edge detect. Bit n detects the falling edge of the pin selected in PINTSELn. Read 0: No falling edge has been detected on this pin since Reset or the last time a one was written to this bit. Write 0: no operation. Read 1: a falling edge has been detected since Reset or the last time a one was written to this bit. Write 1: clear falling edge detection for this pin.
Sourcepub const fn set_fdet(&mut self, val: u8)
pub const fn set_fdet(&mut self, val: u8)
Falling edge detect. Bit n detects the falling edge of the pin selected in PINTSELn. Read 0: No falling edge has been detected on this pin since Reset or the last time a one was written to this bit. Write 0: no operation. Read 1: a falling edge has been detected since Reset or the last time a one was written to this bit. Write 1: clear falling edge detection for this pin.