#[repr(transparent)]pub struct Ienf(pub u32);Expand description
Pin interrupt active level or falling edge interrupt enable register
Tuple Fields
0: u32Implementations
Sourceimpl Ienf
impl Ienf
Sourcepub const fn enaf(&self) -> u8
pub const fn enaf(&self) -> u8
Enables the falling edge or configures the active level interrupt for each pin interrupt. Bit n configures the pin interrupt selected in PINTSELn. 0 = Disable falling edge interrupt or set active interrupt level LOW. 1 = Enable falling edge interrupt enabled or set active interrupt level HIGH.
Sourcepub const fn set_enaf(&mut self, val: u8)
pub const fn set_enaf(&mut self, val: u8)
Enables the falling edge or configures the active level interrupt for each pin interrupt. Bit n configures the pin interrupt selected in PINTSELn. 0 = Disable falling edge interrupt or set active interrupt level LOW. 1 = Enable falling edge interrupt enabled or set active interrupt level HIGH.