nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Ienr

Struct Ienr 

#[repr(transparent)]
pub struct Ienr(pub u32);
Pin interrupt level or rising edge interrupt enable register

Tuple Fields

0: u32

Implementations

Source

impl Ienr

pub const fn enrl(&self) -> u8

Enables the rising edge or level interrupt for each pin interrupt. Bit n configures the pin interrupt selected in PINTSELn. 0 = Disable rising edge or level interrupt. 1 = Enable rising edge or level interrupt.

pub const fn set_enrl(&mut self, val: u8)

Enables the rising edge or level interrupt for each pin interrupt. Bit n configures the pin interrupt selected in PINTSELn. 0 = Disable rising edge or level interrupt. 1 = Enable rising edge or level interrupt.