#[repr(transparent)]pub struct Pmcfg(pub u32);Expand description
Pattern match interrupt bit slice configuration register
Tuple Fields
0: u32Implementations
Sourceimpl Pmcfg
impl Pmcfg
Sourcepub const fn prod_endpts0(&self) -> ProdEndpts0
pub const fn prod_endpts0(&self) -> ProdEndpts0
Determines whether slice 0 is an endpoint.
Sourcepub const fn set_prod_endpts0(&mut self, val: ProdEndpts0)
pub const fn set_prod_endpts0(&mut self, val: ProdEndpts0)
Determines whether slice 0 is an endpoint.
Sourcepub const fn prod_endpts1(&self) -> ProdEndpts1
pub const fn prod_endpts1(&self) -> ProdEndpts1
Determines whether slice 1 is an endpoint.
Sourcepub const fn set_prod_endpts1(&mut self, val: ProdEndpts1)
pub const fn set_prod_endpts1(&mut self, val: ProdEndpts1)
Determines whether slice 1 is an endpoint.
Sourcepub const fn prod_endpts2(&self) -> ProdEndpts2
pub const fn prod_endpts2(&self) -> ProdEndpts2
Determines whether slice 2 is an endpoint.
Sourcepub const fn set_prod_endpts2(&mut self, val: ProdEndpts2)
pub const fn set_prod_endpts2(&mut self, val: ProdEndpts2)
Determines whether slice 2 is an endpoint.
Sourcepub const fn prod_endpts3(&self) -> ProdEndpts3
pub const fn prod_endpts3(&self) -> ProdEndpts3
Determines whether slice 3 is an endpoint.
Sourcepub const fn set_prod_endpts3(&mut self, val: ProdEndpts3)
pub const fn set_prod_endpts3(&mut self, val: ProdEndpts3)
Determines whether slice 3 is an endpoint.
Sourcepub const fn prod_endpts4(&self) -> ProdEndpts4
pub const fn prod_endpts4(&self) -> ProdEndpts4
Determines whether slice 4 is an endpoint.
Sourcepub const fn set_prod_endpts4(&mut self, val: ProdEndpts4)
pub const fn set_prod_endpts4(&mut self, val: ProdEndpts4)
Determines whether slice 4 is an endpoint.
Sourcepub const fn prod_endpts5(&self) -> ProdEndpts5
pub const fn prod_endpts5(&self) -> ProdEndpts5
Determines whether slice 5 is an endpoint.
Sourcepub const fn set_prod_endpts5(&mut self, val: ProdEndpts5)
pub const fn set_prod_endpts5(&mut self, val: ProdEndpts5)
Determines whether slice 5 is an endpoint.
Sourcepub const fn prod_endpts6(&self) -> ProdEndpts6
pub const fn prod_endpts6(&self) -> ProdEndpts6
Determines whether slice 6 is an endpoint.
Sourcepub const fn set_prod_endpts6(&mut self, val: ProdEndpts6)
pub const fn set_prod_endpts6(&mut self, val: ProdEndpts6)
Determines whether slice 6 is an endpoint.
Sourcepub const fn set_cfg0(&mut self, val: Cfg0)
pub const fn set_cfg0(&mut self, val: Cfg0)
Specifies the match contribution condition for bit slice 0.
Sourcepub const fn set_cfg1(&mut self, val: Cfg1)
pub const fn set_cfg1(&mut self, val: Cfg1)
Specifies the match contribution condition for bit slice 1.
Sourcepub const fn set_cfg2(&mut self, val: Cfg2)
pub const fn set_cfg2(&mut self, val: Cfg2)
Specifies the match contribution condition for bit slice 2.
Sourcepub const fn set_cfg3(&mut self, val: Cfg3)
pub const fn set_cfg3(&mut self, val: Cfg3)
Specifies the match contribution condition for bit slice 3.
Sourcepub const fn set_cfg4(&mut self, val: Cfg4)
pub const fn set_cfg4(&mut self, val: Cfg4)
Specifies the match contribution condition for bit slice 4.
Sourcepub const fn set_cfg5(&mut self, val: Cfg5)
pub const fn set_cfg5(&mut self, val: Cfg5)
Specifies the match contribution condition for bit slice 5.