#[repr(transparent)]pub struct Pmctrl(pub u32);Expand description
Pattern match interrupt control register
Tuple Fields
0: u32Implementations
Sourceimpl Pmctrl
impl Pmctrl
Sourcepub const fn sel_pmatch(&self) -> SelPmatch
pub const fn sel_pmatch(&self) -> SelPmatch
Specifies whether the 8 pin interrupts are controlled by the pin interrupt function or by the pattern match function.
Sourcepub const fn set_sel_pmatch(&mut self, val: SelPmatch)
pub const fn set_sel_pmatch(&mut self, val: SelPmatch)
Specifies whether the 8 pin interrupts are controlled by the pin interrupt function or by the pattern match function.
Sourcepub const fn ena_rxev(&self) -> bool
pub const fn ena_rxev(&self) -> bool
Enables the RXEV output to the CPU and/or to a GPIO output when the specified boolean expression evaluates to true.
Sourcepub const fn set_ena_rxev(&mut self, val: bool)
pub const fn set_ena_rxev(&mut self, val: bool)
Enables the RXEV output to the CPU and/or to a GPIO output when the specified boolean expression evaluates to true.