#[repr(transparent)]pub struct Sienf(pub u32);Expand description
Pin interrupt active level or falling edge interrupt set register
Tuple Fields
0: u32Implementations
Sourceimpl Sienf
impl Sienf
Sourcepub const fn setenaf(&self) -> u8
pub const fn setenaf(&self) -> u8
Ones written to this address set bits in the IENF, thus enabling interrupts. Bit n sets bit n in the IENF register. 0 = No operation. 1 = Select HIGH-active interrupt or enable falling edge interrupt.
Sourcepub const fn set_setenaf(&mut self, val: u8)
pub const fn set_setenaf(&mut self, val: u8)
Ones written to this address set bits in the IENF, thus enabling interrupts. Bit n sets bit n in the IENF register. 0 = No operation. 1 = Select HIGH-active interrupt or enable falling edge interrupt.