nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Sienr

Struct Sienr 

#[repr(transparent)]
pub struct Sienr(pub u32);
Pin interrupt level or rising edge interrupt set register

Tuple Fields

0: u32

Implementations

Source

impl Sienr

pub const fn setenrl(&self) -> u8

Ones written to this address set bits in the IENR, thus enabling interrupts. Bit n sets bit n in the IENR register. 0 = No operation. 1 = Enable rising edge or level interrupt.

pub const fn set_setenrl(&mut self, val: u8)

Ones written to this address set bits in the IENR, thus enabling interrupts. Bit n sets bit n in the IENR register. 0 = No operation. 1 = Enable rising edge or level interrupt.